==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/ServerConfigurationsManagementSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.ServerConfigurationsManagementSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Set the connectivity, storage and workload settings.
 * @property additionalFeaturesServerConfigurations Additional SQL feature settings.
 * @property sqlConnectivityUpdateSettings SQL connectivity type settings.
 * @property sqlInstanceSettings SQL Instance settings.
 * @property sqlStorageUpdateSettings SQL storage update settings.
 * @property sqlWorkloadTypeUpdateSettings SQL workload type settings.
 */
public data class ServerConfigurationsManagementSettingsArgs(
    public val additionalFeaturesServerConfigurations:
    Output<AdditionalFeaturesServerConfigurationsArgs>? = null,
    public val sqlConnectivityUpdateSettings: Output<SqlConnectivityUpdateSettingsArgs>? = null,
    public val sqlInstanceSettings: Output<SQLInstanceSettingsArgs>? = null,
    public val sqlStorageUpdateSettings: Output<SqlStorageUpdateSettingsArgs>? = null,
    public val sqlWorkloadTypeUpdateSettings: Output<SqlWorkloadTypeUpdateSettingsArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.ServerConfigurationsManagementSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.sqlvirtualmachine.inputs.ServerConfigurationsManagementSettingsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.ServerConfigurationsManagementSettingsArgs.builder()
            .additionalFeaturesServerConfigurations(
                additionalFeaturesServerConfigurations?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .sqlConnectivityUpdateSettings(
                sqlConnectivityUpdateSettings?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .sqlInstanceSettings(
                sqlInstanceSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .sqlStorageUpdateSettings(
                sqlStorageUpdateSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .sqlWorkloadTypeUpdateSettings(
                sqlWorkloadTypeUpdateSettings?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            ).build()
}

/**
 * Builder for [ServerConfigurationsManagementSettingsArgs].
 */
@PulumiTagMarker
public class ServerConfigurationsManagementSettingsArgsBuilder internal constructor() {
    private var additionalFeaturesServerConfigurations:
        Output<AdditionalFeaturesServerConfigurationsArgs>? = null

    private var sqlConnectivityUpdateSettings: Output<SqlConnectivityUpdateSettingsArgs>? = null

    private var sqlInstanceSettings: Output<SQLInstanceSettingsArgs>? = null

    private var sqlStorageUpdateSettings: Output<SqlStorageUpdateSettingsArgs>? = null

    private var sqlWorkloadTypeUpdateSettings: Output<SqlWorkloadTypeUpdateSettingsArgs>? = null

    /**
     * @param value Additional SQL feature settings.
     */
    @JvmName("byrevpnhxiikulmc")
    public suspend
    fun additionalFeaturesServerConfigurations(`value`: Output<AdditionalFeaturesServerConfigurationsArgs>) {
        this.additionalFeaturesServerConfigurations = value
    }

    /**
     * @param value SQL connectivity type settings.
     */
    @JvmName("dccjwgleyvwwgclr")
    public suspend
    fun sqlConnectivityUpdateSettings(`value`: Output<SqlConnectivityUpdateSettingsArgs>) {
        this.sqlConnectivityUpdateSettings = value
    }

    /**
     * @param value SQL Instance settings.
     */
    @JvmName("pxlsvakfvastdfof")
    public suspend fun sqlInstanceSettings(`value`: Output<SQLInstanceSettingsArgs>) {
        this.sqlInstanceSettings = value
    }

    /**
     * @param value SQL storage update settings.
     */
    @JvmName("rpqopuqqhntohekl")
    public suspend fun sqlStorageUpdateSettings(`value`: Output<SqlStorageUpdateSettingsArgs>) {
        this.sqlStorageUpdateSettings = value
    }

    /**
     * @param value SQL workload type settings.
     */
    @JvmName("ckyjfdqvstihfavi")
    public suspend
    fun sqlWorkloadTypeUpdateSettings(`value`: Output<SqlWorkloadTypeUpdateSettingsArgs>) {
        this.sqlWorkloadTypeUpdateSettings = value
    }

    /**
     * @param value Additional SQL feature settings.
     */
    @JvmName("lshtiaajuoljayum")
    public suspend
    fun additionalFeaturesServerConfigurations(`value`: AdditionalFeaturesServerConfigurationsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalFeaturesServerConfigurations = mapped
    }

    /**
     * @param argument Additional SQL feature settings.
     */
    @JvmName("upwsefmeidjhttqi")
    public suspend
    fun additionalFeaturesServerConfigurations(argument: suspend AdditionalFeaturesServerConfigurationsArgsBuilder.() -> Unit) {
        val toBeMapped = AdditionalFeaturesServerConfigurationsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.additionalFeaturesServerConfigurations = mapped
    }

    /**
     * @param value SQL connectivity type settings.
     */
    @JvmName("mainrdtotqnqjamu")
    public suspend fun sqlConnectivityUpdateSettings(`value`: SqlConnectivityUpdateSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlConnectivityUpdateSettings = mapped
    }

    /**
     * @param argument SQL connectivity type settings.
     */
    @JvmName("cuoaysdwvdkookvt")
    public suspend
    fun sqlConnectivityUpdateSettings(argument: suspend SqlConnectivityUpdateSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectivityUpdateSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sqlConnectivityUpdateSettings = mapped
    }

    /**
     * @param value SQL Instance settings.
     */
    @JvmName("erpoiktcpgboetjn")
    public suspend fun sqlInstanceSettings(`value`: SQLInstanceSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlInstanceSettings = mapped
    }

    /**
     * @param argument SQL Instance settings.
     */
    @JvmName("qvaclfpygetiawxp")
    public suspend
    fun sqlInstanceSettings(argument: suspend SQLInstanceSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SQLInstanceSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sqlInstanceSettings = mapped
    }

    /**
     * @param value SQL storage update settings.
     */
    @JvmName("fhdlgqxqnokkspvj")
    public suspend fun sqlStorageUpdateSettings(`value`: SqlStorageUpdateSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlStorageUpdateSettings = mapped
    }

    /**
     * @param argument SQL storage update settings.
     */
    @JvmName("kihrlucwqpidiroj")
    public suspend
    fun sqlStorageUpdateSettings(argument: suspend SqlStorageUpdateSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SqlStorageUpdateSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sqlStorageUpdateSettings = mapped
    }

    /**
     * @param value SQL workload type settings.
     */
    @JvmName("wqtyvnoqwmxxhuhy")
    public suspend fun sqlWorkloadTypeUpdateSettings(`value`: SqlWorkloadTypeUpdateSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlWorkloadTypeUpdateSettings = mapped
    }

    /**
     * @param argument SQL workload type settings.
     */
    @JvmName("ghubkwdcpppvpjtf")
    public suspend
    fun sqlWorkloadTypeUpdateSettings(argument: suspend SqlWorkloadTypeUpdateSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SqlWorkloadTypeUpdateSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sqlWorkloadTypeUpdateSettings = mapped
    }

    internal fun build(): ServerConfigurationsManagementSettingsArgs =
        ServerConfigurationsManagementSettingsArgs(
            additionalFeaturesServerConfigurations = additionalFeaturesServerConfigurations,
            sqlConnectivityUpdateSettings = sqlConnectivityUpdateSettings,
            sqlInstanceSettings = sqlInstanceSettings,
            sqlStorageUpdateSettings = sqlStorageUpdateSettings,
            sqlWorkloadTypeUpdateSettings = sqlWorkloadTypeUpdateSettings,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/ServerConfigurationsManagementSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.ServerConfigurationsManagementSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Set the connectivity, storage and workload settings.
 * @property additionalFeaturesServerConfigurations Additional SQL feature settings.
 * @property sqlConnectivityUpdateSettings SQL connectivity type settings.
 * @property sqlInstanceSettings SQL Instance settings.
 * @property sqlStorageUpdateSettings SQL storage update settings.
 * @property sqlWorkloadTypeUpdateSettings SQL workload type settings.
 */
public data class ServerConfigurationsManagementSettingsArgs(
    public val additionalFeaturesServerConfigurations:
    Output<AdditionalFeaturesServerConfigurationsArgs>? = null,
    public val sqlConnectivityUpdateSettings: Output<SqlConnectivityUpdateSettingsArgs>? = null,
    public val sqlInstanceSettings: Output<SQLInstanceSettingsArgs>? = null,
    public val sqlStorageUpdateSettings: Output<SqlStorageUpdateSettingsArgs>? = null,
    public val sqlWorkloadTypeUpdateSettings: Output<SqlWorkloadTypeUpdateSettingsArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.ServerConfigurationsManagementSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.sqlvirtualmachine.inputs.ServerConfigurationsManagementSettingsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.ServerConfigurationsManagementSettingsArgs.builder()
            .additionalFeaturesServerConfigurations(
                additionalFeaturesServerConfigurations?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .sqlConnectivityUpdateSettings(
                sqlConnectivityUpdateSettings?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .sqlInstanceSettings(
                sqlInstanceSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .sqlStorageUpdateSettings(
                sqlStorageUpdateSettings?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .sqlWorkloadTypeUpdateSettings(
                sqlWorkloadTypeUpdateSettings?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            ).build()
}

/**
 * Builder for [ServerConfigurationsManagementSettingsArgs].
 */
@PulumiTagMarker
public class ServerConfigurationsManagementSettingsArgsBuilder internal constructor() {
    private var additionalFeaturesServerConfigurations:
        Output<AdditionalFeaturesServerConfigurationsArgs>? = null

    private var sqlConnectivityUpdateSettings: Output<SqlConnectivityUpdateSettingsArgs>? = null

    private var sqlInstanceSettings: Output<SQLInstanceSettingsArgs>? = null

    private var sqlStorageUpdateSettings: Output<SqlStorageUpdateSettingsArgs>? = null

    private var sqlWorkloadTypeUpdateSettings: Output<SqlWorkloadTypeUpdateSettingsArgs>? = null

    /**
     * @param value Additional SQL feature settings.
     */
    @JvmName("lfqkuxlyhagrxgio")
    public suspend
    fun additionalFeaturesServerConfigurations(`value`: Output<AdditionalFeaturesServerConfigurationsArgs>) {
        this.additionalFeaturesServerConfigurations = value
    }

    /**
     * @param value SQL connectivity type settings.
     */
    @JvmName("slkvdugecnukaswv")
    public suspend
    fun sqlConnectivityUpdateSettings(`value`: Output<SqlConnectivityUpdateSettingsArgs>) {
        this.sqlConnectivityUpdateSettings = value
    }

    /**
     * @param value SQL Instance settings.
     */
    @JvmName("ctuiinydrcinelwc")
    public suspend fun sqlInstanceSettings(`value`: Output<SQLInstanceSettingsArgs>) {
        this.sqlInstanceSettings = value
    }

    /**
     * @param value SQL storage update settings.
     */
    @JvmName("qfurklawiiiechey")
    public suspend fun sqlStorageUpdateSettings(`value`: Output<SqlStorageUpdateSettingsArgs>) {
        this.sqlStorageUpdateSettings = value
    }

    /**
     * @param value SQL workload type settings.
     */
    @JvmName("kfyhohulciyptdxq")
    public suspend
    fun sqlWorkloadTypeUpdateSettings(`value`: Output<SqlWorkloadTypeUpdateSettingsArgs>) {
        this.sqlWorkloadTypeUpdateSettings = value
    }

    /**
     * @param value Additional SQL feature settings.
     */
    @JvmName("aactwcklvnepmcpi")
    public suspend
    fun additionalFeaturesServerConfigurations(`value`: AdditionalFeaturesServerConfigurationsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalFeaturesServerConfigurations = mapped
    }

    /**
     * @param argument Additional SQL feature settings.
     */
    @JvmName("oanjirbxmwericqp")
    public suspend
    fun additionalFeaturesServerConfigurations(argument: suspend AdditionalFeaturesServerConfigurationsArgsBuilder.() -> Unit) {
        val toBeMapped = AdditionalFeaturesServerConfigurationsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.additionalFeaturesServerConfigurations = mapped
    }

    /**
     * @param value SQL connectivity type settings.
     */
    @JvmName("eciqpjbhvbsawmor")
    public suspend fun sqlConnectivityUpdateSettings(`value`: SqlConnectivityUpdateSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlConnectivityUpdateSettings = mapped
    }

    /**
     * @param argument SQL connectivity type settings.
     */
    @JvmName("hrbuvyetcjlguggi")
    public suspend
    fun sqlConnectivityUpdateSettings(argument: suspend SqlConnectivityUpdateSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SqlConnectivityUpdateSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sqlConnectivityUpdateSettings = mapped
    }

    /**
     * @param value SQL Instance settings.
     */
    @JvmName("sscauggyglpxxiph")
    public suspend fun sqlInstanceSettings(`value`: SQLInstanceSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlInstanceSettings = mapped
    }

    /**
     * @param argument SQL Instance settings.
     */
    @JvmName("xgqijcwdwndjehds")
    public suspend
    fun sqlInstanceSettings(argument: suspend SQLInstanceSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SQLInstanceSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sqlInstanceSettings = mapped
    }

    /**
     * @param value SQL storage update settings.
     */
    @JvmName("stiuscbysqbpsvgk")
    public suspend fun sqlStorageUpdateSettings(`value`: SqlStorageUpdateSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlStorageUpdateSettings = mapped
    }

    /**
     * @param argument SQL storage update settings.
     */
    @JvmName("ufomaihihyednlmc")
    public suspend
    fun sqlStorageUpdateSettings(argument: suspend SqlStorageUpdateSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SqlStorageUpdateSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sqlStorageUpdateSettings = mapped
    }

    /**
     * @param value SQL workload type settings.
     */
    @JvmName("oeuwuunkkewlffdm")
    public suspend fun sqlWorkloadTypeUpdateSettings(`value`: SqlWorkloadTypeUpdateSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlWorkloadTypeUpdateSettings = mapped
    }

    /**
     * @param argument SQL workload type settings.
     */
    @JvmName("tqkdsdyxbotjoixa")
    public suspend
    fun sqlWorkloadTypeUpdateSettings(argument: suspend SqlWorkloadTypeUpdateSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = SqlWorkloadTypeUpdateSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sqlWorkloadTypeUpdateSettings = mapped
    }

    internal fun build(): ServerConfigurationsManagementSettingsArgs =
        ServerConfigurationsManagementSettingsArgs(
            additionalFeaturesServerConfigurations = additionalFeaturesServerConfigurations,
            sqlConnectivityUpdateSettings = sqlConnectivityUpdateSettings,
            sqlInstanceSettings = sqlInstanceSettings,
            sqlStorageUpdateSettings = sqlStorageUpdateSettings,
            sqlWorkloadTypeUpdateSettings = sqlWorkloadTypeUpdateSettings,
        )
}
